#include <osgGA/Version>

const char* osgGAGetVersion()
{
    return "1.1";
}


const char* osgGAGetLibraryName()
{
    return "OpenSceneGraph Gui Adapter Library";
}
